@@ -103,5 +103,6 @@ class Server(object):
 
     def run(self):
         logger.debug(f'启动服务器：http://127.0.0.1:{self.port}')
-        self.thread = threading.Thread(target=waitress.serve, args=(self.app,), kwargs={'port': self.port}, daemon=True)
+        self.thread = threading.Thread(target=waitress.serve, args=(self.app,),
+                                       kwargs={'port': self.port, '_quiet': True}, daemon=True)
         self.thread.start()
